@@ -51,8 +51,12 @@ class WSDLService(object):
         获取入口
         """
         for sub in self.documents:
-            if sub.tag.endswith('service'):
-                service_root = sub
+            try:
+                if sub.tag.endswith('service'):
+                    service_root = sub
+                    break
+            except Exception as e:
+                print(f'{e}')
         if service_root:
             for sub in service_root:
                 if not sub.tag.endswith('port'):
