@@ -32,7 +32,7 @@ def project(wsdl):
     with open('./wsdl.xml', 'w') as f:
         f.write(wsdl)
     for port in service.ports():
-        with open(f'./{port}.xml', 'w') as f:
+        with open('./{}.xml'.format(port), 'w') as f:
             f.write(EMPTY_SOAP_RESPONSE)
     print("Project Generated!")
 
